Please see [https://docs.mlcommons.org/cm4mlops/scripts/AI-ML-datasets/get-dataset-imagenet-train](https://docs.mlcommons.org/cm4mlops/scripts/AI-ML-datasets/get-dataset-imagenet-train) for the documentation of this CM script.
